


# OAuth 2.x

- https://www.rfc-editor.org/rfc/rfc8707.html

# Resources

- https://tyk.io/blog/your-data-model-is-not-an-api/
- https://shekhargulati.com/2021/10/15/web-api-design-anti-pattern-exposing-your-database-model
- https://cloud.google.com/blog/products/api-management/why-your-web-apis-should-be-entity-oriented
- https://cloud.google.com/blog/products/application-development/api-design-why-you-should-use-links-not-keys-to-represent-relationships-in-apis
- https://tools.ietf.org/html/rfc7807
- https://www.iana.org/assignments/link-relations/link-relations.xhtml
- https://thorben-janssen.com/dont-expose-entities-in-api/
- https://vaadin.com/blog/ddd-part-3-domain-driven-design-and-the-hexagonal-architecture
